@@ -1,11 +1,11 @@
 ;;; cape.el --- Completion At Point Extensions -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2025 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Version: 1.8
+;; Version: 1.9
 ;; Package-Requires: ((emacs "28.1") (compat "30"))
 ;; URL: https://github.com/minad/cape
 ;; Keywords: abbrev, convenience, matching, completion, text
@@ -937,11 +937,7 @@ multiple super Capfs in the `completion-at-point-functions':
       `( ,beg ,end
          ,(lambda (str pred action)
             (pcase action
-              (`(boundaries . ,_) nil)
-              ('metadata
-               '(metadata (category . cape-super)
-                          (display-sort-function . identity)
-                          (cycle-sort-function . identity)))
+              ((or `(boundaries . ,_) 'metadata) nil)
               ('t ;; all-completions
                (let ((ht (make-hash-table :test #'equal))
                      (candidates nil))
@@ -986,6 +982,9 @@ multiple super Capfs in the `completion-at-point-functions':
                              (lambda (x) (and (funcall table-pred x) (funcall pred x)))
                            (or table-pred pred)))))))
          :company-prefix-length ,prefix-len
+         :category cape-super
+         :display-sort-function identity
+         :cycle-sort-function identity
          ,@(and (not exclusive) '(:exclusive no))
          ,@(mapcan
             (lambda (prop)
